passotp is a CLI to add OTP passwords for Pass

Instalation
===========
pip install passotp

Usage
=====
passotp <pass-name> [-c]

Prepare your pass files
=======================
You shoud add a line containing "OTP: <secret>" (Warning: the "OTP" is not case sensitive yet issue #1)
